/// @description Player Setup

// controls
left = vk_left;
right = vk_right;
jump = vk_space;
down = ord("S");
dash = vk_shift;

// basic variables
controls = 1;															// whether the player has control over the character
baseSpeed = 2;															// basic maximum player speed
baseAcceleration = 0.5;													// acceleration per frame
baseFriction = 1.8;														// friction for stopping
onGround = 0;															// whether the player is currently grounded
jumpForce = -4;															// jump force
jumpModifier = 1.2;														// modifier for letting go of space early
baseGravity = 0.2;														// default gravity
currentGravity = baseGravity;											// force currently affecting the player
maxVSp = 20;															// terminal velocity
hSp = 0;																// h speed on this frame
vSp = 0;																// v speed on this frame

hasDoubleJump = 1;														// whether the player can double jump
doubleJumped = 1;														// whether the player has used his double jump
hasDash = 1;															// whether the player can dash
dashEnabled = 1;														// whether player has dash available
dashMode = 0;															// whether player is in dash mode
dashForce = 20;															// length of dash
dashFriction = 1.1;														// friction coming out of a dash

currentRot = 0;															// current sprite rotation
rotSpeed = -4;															// rotation speed multiplier
sineFloat = 0;															// current floating animation cycle
sineSpeed = 0.1;														// speed of floating animation
OOBm = 100;																// out of bounds buffer zone
okToDestroy = 0;														// whether destroying the player is ok (ie in cutscenes)
springJump = 0;															// whether the last jump was initiated by a spring
endaction = 0;															// whether the levels final cutscene triggered
blockSoundPlayed = 0;													// the surprise
hasJump = 1;															// the ultra surprise

// if a save exists, respawn there
if (global.savedX != 0) {
	x = global.savedX;
	y = global.savedY;
} else {
	global.savedX = x;
	global.savedY = y;
}

if (global.disableDash) {
	hasJump = 0;
}

if (global.disableDJ) {
	hasDoubleJump = 0;
}

// replace all broken objects
with (obj_breakableWallPlaceholder) {
	var block = instance_create_layer(x, y, "Instances", obj_breakableWall);
	block.image_xscale = savedSizeX;
	block.image_yscale = savedSizeY;
	
	instance_destroy();
}

with (obj_orb) {
	image_index = 0;
	active = 1;
}

with (obj_bullet) {
	instance_destroy();
}

// create some important objects
if (!instance_exists(obj_timer)) {
	instance_create_layer(0, 0, "tech", obj_timer);
}

obj_timer.running = 1;

if (instance_exists(obj_camera)) {
	with (obj_camera) {
		instance_destroy();
	}
}
instance_create_layer(x, y, "tech", obj_camera);